#include "common.h"

/* program name - global variable */

const char *command_name = "u2d";
const char *version_string = "1.3";

/* function prototype */

void parse_long_options (int argc, char **argv, const char *command_name,
			 const char *version_string, void (*usage) ());

void
main (int argc, char **argv)
{
  int n;
  FILE *fpin, *fpout;
  char input_filename[BUFSIZ], output_filename[BUFSIZ];
  char buffer_in;

  /* no argument given */

  if (argc < 2)
    {
      usage ();
      exit (1);
    }

  /* multiple argument */

  for (n = 1; n < argc; n++)
    {
      int ret;

      parse_long_options (argc, argv, command_name, version_string, usage);

      /* check whether argument(file) is directory */

      ret = isdir (argv[n]);

      if (ret == DIR)
	{
	  fprintf (stderr, "%s: %s: is a directory\n",
		   command_name, argv[n]);
	  continue;
	}

      /* check whether file is dos-text or unix-text */

      ret = check_text (argv[n]);

      if (ret == DOSTEXT)
	{
	  fprintf (stderr, "%s: %s: is not a unix text\n",
		   command_name, argv[n]);
	  continue;
	}

      /* naming files */
      strcpy (output_filename, argv[n]);	/* filename to write */
      strcpy (input_filename, argv[n]);

      /* open to read */
      if ((fpin = fopen (input_filename, "r")) == NULL)
	{
	  error (input_filename, strerror (errno));
	  continue;
	}

      strcat (input_filename, "~");	/* filename to backup */

      rename (output_filename, input_filename);

      /* open to write */
      if ((fpout = fopen (output_filename, "w")) == NULL)
	{
	  error (output_filename, strerror (errno));
	  continue;
	}

      /* main loop */
      while ((buffer_in = fgetc (fpin)) != EOF)
	{
	  /* remove ^Z & ^M */
	  if (buffer_in != CRTL_Z && buffer_in != CRTL_M)
	    {
	      if (buffer_in == '\n')	/* add ^M */
		fputs ("\r\n", fpout);
	      else
		fputc (buffer_in, fpout);
	    }
	}

      fclose (fpout);
      fclose (fpin);
    }
  exit (0);
}
